# fstotv
send video in local to chromecast


```bash
pip3 install fstotv
```

```bash
fstotv example.mp4
```
or
```bash
fstotv example.mp4 "ip of the computer that executes the command (if you have several networks this will be necessary)"
```
